@@ -57,12 +57,12 @@ typedef enum {
  *   depending on whether this is a hybrid cgroup layout (mix of legacy and
  *   unified hierarchies) or a pure unified cgroup layout.
  *
- * @base_cgroup
+ * @container_base_path
  * - The cgroup under which the container cgroup path
  *   is created. This will be either the caller's cgroup (if not root), or
  *   init's cgroup (if root).
  *
- * @fullcgpath
+ * @container_full_path
  * - The full path to the containers cgroup.
  *
  * @version
@@ -76,8 +76,8 @@ typedef enum {
 struct hierarchy {
 	char **controllers;
 	char *mountpoint;
-	char *base_cgroup;
-	char *fullcgpath;
+	char *container_base_path;
+	char *container_full_path;
 	int version;
 };
 
@@ -99,6 +99,7 @@ struct cgroup_ops {
 	 *   hierarchy wins.
 	 */
 	struct hierarchy **hierarchies;
+	/* Pointer to the unified hierarchy. Do not free! */
 	struct hierarchy *unified;
 
 	/*
@@ -124,8 +125,8 @@ struct cgroup_ops {
 
 	bool (*data_init)(struct cgroup_ops *ops);
 	void (*destroy)(struct cgroup_ops *ops, struct lxc_handler *handler);
-	bool (*create)(struct cgroup_ops *ops, struct lxc_handler *handler);
-	bool (*enter)(struct cgroup_ops *ops, pid_t pid);
+	bool (*payload_create)(struct cgroup_ops *ops, struct lxc_handler *handler);
+	bool (*payload_enter)(struct cgroup_ops *ops, pid_t pid);
 	const char *(*get_cgroup)(struct cgroup_ops *ops, const char *controller);
 	bool (*escape)(const struct cgroup_ops *ops);
 	int (*num_hierarchies)(struct cgroup_ops *ops);
