@@ -21,17 +21,21 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
-#define _GNU_SOURCE
-#include <sys/types.h>
-#include <sys/stat.h>
+#ifndef _GNU_SOURCE
+#define _GNU_SOURCE 1
+#endif
 #include <errno.h>
-#include <unistd.h>
-#include <stdlib.h>
 #include <stdio.h>
+#include <stdlib.h>
+#include <sys/stat.h>
+#include <sys/types.h>
+#include <unistd.h>
 
 #include "conf.h"
+#include "config.h"
 #include "log.h"
 #include "start.h"
+#include "raw_syscalls.h"
 #include "utils.h"
 
 lxc_log_define(execute, start);
@@ -40,9 +44,8 @@ static int execute_start(struct lxc_handler *handler, void* data)
 {
 	int argc_add, j;
 	char **argv;
-	int argc = 0, i = 0, logfd = -1;
+	int argc = 0, i = 0;
 	struct execute_args *my_args = data;
-	char logfile[LXC_PROC_PID_FD_LEN];
 
 	while (my_args->argv[argc++]);
 
@@ -54,12 +57,6 @@ static int execute_start(struct lxc_handler *handler, void* data)
 	if (!handler->conf->rootfs.path)
 		argc_add += 2;
 
-	if (lxc_log_has_valid_level())
-		argc_add += 2;
-
-	if (current_config->logfd != -1 || lxc_log_fd != -1)
-		argc_add += 2;
-
 	argv = malloc((argc + argc_add) * sizeof(*argv));
 	if (!argv) {
 		SYSERROR("Allocating init args failed");
@@ -74,32 +71,6 @@ static int execute_start(struct lxc_handler *handler, void* data)
 	argv[i++] = "-n";
 	argv[i++] = (char *)handler->name;
 
-	if (lxc_log_has_valid_level()) {
-		argv[i++] = "-l";
-		argv[i++] = (char *)lxc_log_priority_to_string(lxc_log_get_level());
-	}
-
-	if (current_config->logfd != -1 || lxc_log_fd != -1) {
-		int ret;
-		int to_dup = current_config->logfd;
-
-		if (current_config->logfd == -1)
-			to_dup = lxc_log_fd;
-
-		logfd = dup(to_dup);
-		if (logfd < 0) {
-			SYSERROR("Failed to duplicate log file descriptor");
-			goto out2;
-		}
-
-		ret = snprintf(logfile, sizeof(logfile), "/proc/1/fd/%d", logfd);
-		if (ret < 0 || (size_t)ret >= sizeof(logfile))
-			goto out3;
-
-		argv[i++] = "-o";
-		argv[i++] = logfile;
-	}
-
 	if (my_args->quiet)
 		argv[i++] = "--quiet";
 
@@ -116,18 +87,11 @@ static int execute_start(struct lxc_handler *handler, void* data)
 	NOTICE("Exec'ing \"%s\"", my_args->argv[0]);
 
 	if (my_args->init_fd >= 0)
-#ifdef __NR_execveat
-		syscall(__NR_execveat, my_args->init_fd, "", argv, environ, AT_EMPTY_PATH);
-#else
-		ERROR("System seems to be missing execveat syscall number");
-#endif
+		lxc_raw_execveat(my_args->init_fd, "", argv, environ, AT_EMPTY_PATH);
 	else
 		execvp(argv[0], argv);
 	SYSERROR("Failed to exec %s", argv[0]);
 
-out3:
-	close(logfd);
-out2:
 	free(argv);
 out1:
 	return 1;
@@ -147,12 +111,12 @@ static struct lxc_operations execute_start_ops = {
 
 int lxc_execute(const char *name, char *const argv[], int quiet,
 		struct lxc_handler *handler, const char *lxcpath,
-		bool backgrounded, int *error_num)
+		bool daemonize, int *error_num)
 {
 	struct execute_args args = {.argv = argv, .quiet = quiet};
 
 	TRACE("Doing lxc_execute");
 	handler->conf->is_execute = true;
 	return __lxc_start(name, handler, &execute_start_ops, &args, lxcpath,
-			   backgrounded, error_num);
+			   daemonize, error_num);
 }
