@@ -20,25 +20,28 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
-#include "config.h"
 
+#ifndef _GNU_SOURCE
+#define _GNU_SOURCE 1
+#endif
+#include <errno.h>
+#include <fcntl.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <errno.h>
-#include <unistd.h>
 #include <string.h>
-#include <fcntl.h>
-#include <sys/types.h>
 #include <sys/param.h>
+#include <sys/types.h>
+#include <unistd.h>
 
 #include "cgroup.h"
 #include "commands.h"
+#include "config.h"
 #include "error.h"
 #include "log.h"
 #include "lxc.h"
 #include "monitor.h"
-#include "parse.h"
 #include "state.h"
+#include "string_utils.h"
 
 lxc_log_define(freezer, lxc);
 
