@@ -24,8 +24,6 @@
 #ifndef __LXC_LOG_H
 #define __LXC_LOG_H
 
-#include "config.h"
-
 #include <errno.h>
 #include <stdarg.h>
 #include <stdio.h>
@@ -276,6 +274,7 @@ ATTR_UNUSED static inline void LXC_##LEVEL(struct lxc_log_locinfo* locinfo,	\
 {										\
 	if (lxc_log_priority_is_enabled(acategory, LXC_LOG_LEVEL_##LEVEL)) {	\
 		va_list va_ref;							\
+		int saved_errno;						\
 		struct lxc_log_event evt = {					\
 			.category	= (acategory)->name,			\
 			.priority	= LXC_LOG_LEVEL_##LEVEL,		\
@@ -287,12 +286,14 @@ ATTR_UNUSED static inline void LXC_##LEVEL(struct lxc_log_locinfo* locinfo,	\
 		 * without restrictions. So let's use it for our		\
 		 * logging stamps.						\
 		 */								\
+		saved_errno = errno;						\
 		(void)clock_gettime(CLOCK_REALTIME, &evt.timestamp);		\
 										\
 		va_start(va_ref, format);					\
 		evt.vap = &va_ref;						\
 		__lxc_log(acategory, &evt);					\
 		va_end(va_ref);							\
+		errno = saved_errno;						\
 	}									\
 }
 
@@ -327,22 +328,44 @@ ATTR_UNUSED static inline void LXC_##LEVEL(struct lxc_log_locinfo* locinfo,	\
 /*
  * Helper macro to define errno string.
  */
-#if (_POSIX_C_SOURCE >= 200112L || _XOPEN_SOURCE >= 600) && !defined(_GNU_SOURCE) || IS_BIONIC
-#define lxc_log_strerror_r                                               \
-	char errno_buf[MAXPATHLEN / 2] = {"Failed to get errno string"}; \
-	char *ptr = errno_buf;                                           \
-	{                                                                \
-		(void)strerror_r(errno, errno_buf, sizeof(errno_buf));   \
-	}
+#if HAVE_STRERROR_R
+	#ifndef HAVE_DECL_STRERROR_R
+		#ifdef STRERROR_R_CHAR_P
+			char *strerror_r(int errnum, char *buf, size_t buflen);
+		#else
+			int strerror_r(int errnum, char *buf, size_t buflen);
+		#endif
+	#endif
+
+	#ifdef STRERROR_R_CHAR_P
+		#define lxc_log_strerror_r                                               \
+			char errno_buf[PATH_MAX / 2] = {"Failed to get errno string"};   \
+			char *ptr = NULL;                                                \
+			{                                                                \
+				int saved_errno = errno;				 \
+				ptr = strerror_r(errno, errno_buf, sizeof(errno_buf));   \
+				errno = saved_errno;					 \
+				if (!ptr)                                                \
+					ptr = errno_buf;                                 \
+			}
+	#else
+		#define lxc_log_strerror_r                                               \
+			char errno_buf[PATH_MAX / 2] = {"Failed to get errno string"};   \
+			char *ptr = errno_buf;                                           \
+			{                                                                \
+				int saved_errno = errno;				 \
+				(void)strerror_r(errno, errno_buf, sizeof(errno_buf));   \
+				errno = saved_errno;					 \
+			}
+	#endif
+#elif ENFORCE_THREAD_SAFETY
+	#error ENFORCE_THREAD_SAFETY was set but cannot be guaranteed
 #else
-#define lxc_log_strerror_r                                               \
-	char errno_buf[MAXPATHLEN / 2] = {"Failed to get errno string"}; \
-	char *ptr;                                                       \
-	{                                                                \
-		ptr = strerror_r(errno, errno_buf, sizeof(errno_buf));   \
-		if (!ptr)                                                \
-			ptr = errno_buf;                                 \
-	}
+	#define lxc_log_strerror_r							 \
+		char *ptr = NULL;              						 \
+		{                              						 \
+			ptr = strerror(errno); 						 \
+		}
 #endif
 
 /*
@@ -452,5 +475,5 @@ extern int lxc_log_set_file(int *fd, const char *fname);
 extern const char *lxc_log_get_file(void);
 extern void lxc_log_set_prefix(const char *prefix);
 extern const char *lxc_log_get_prefix(void);
-extern void lxc_log_options_no_override();
+extern void lxc_log_options_no_override(void);
 #endif
