@@ -31,6 +31,7 @@ extern "C" {
 #include <stddef.h>
 #include <sys/select.h>
 #include <sys/types.h>
+
 #include "state.h"
 
 struct lxc_msg;
@@ -47,27 +48,27 @@ struct lxc_handler;
 /*
  * Start the specified command inside a system container
  * @name         : the name of the container
- * @argv         : an array of char * corresponding to the commande line
+ * @argv         : an array of char * corresponding to the command line
  * @conf         : configuration
- * @backgrounded : whether or not the container is daemonized
+ * @daemonize    : whether or not the container is daemonized
  * Returns 0 on success, < 0 otherwise
  */
 extern int lxc_start(const char *name, char *const argv[],
 		     struct lxc_handler *handler, const char *lxcpath,
-		     bool backgrounded, int *error_num);
+		     bool daemonize, int *error_num);
 
 /*
  * Start the specified command inside an application container
  * @name         : the name of the container
- * @argv         : an array of char * corresponding to the commande line
+ * @argv         : an array of char * corresponding to the command line
  * @quiet        : if != 0 then lxc-init won't produce any output
  * @conf         : configuration
- * @backgrounded : whether or not the container is daemonized
+ * @daemonize    : whether or not the container is daemonized
  * Returns 0 on success, < 0 otherwise
  */
 extern int lxc_execute(const char *name, char *const argv[], int quiet,
 		       struct lxc_handler *handler, const char *lxcpath,
-		       bool backgrounded, int *error_num);
+		       bool daemonize, int *error_num);
 
 /*
  * Close the fd associated with the monitoring
