@@ -24,10 +24,9 @@
 #ifndef __LXC_STORAGE_UTILS_H
 #define __LXC_STORAGE_UTILS_H
 
-#include "config.h"
-#include <stdio.h>
 #include <stdbool.h>
 #include <stdint.h>
+#include <stdio.h>
 
 #include "conf.h"
 
@@ -48,6 +47,7 @@ extern int find_fstype_cb(char *buffer, void *data);
 extern const char *linkderef(const char *path, char *dest);
 extern bool unpriv_snap_allowed(struct lxc_storage *b, const char *t, bool snap,
 				bool maybesnap);
+extern uint64_t get_fssize(char *s);
 extern bool is_valid_storage_type(const char *type);
 extern int storage_destroy_wrapper(void *data);
 
