@@ -22,23 +22,27 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
-#define _GNU_SOURCE
+#ifndef _GNU_SOURCE
+#define _GNU_SOURCE 1
+#endif
 #include <ctype.h>
 #include <errno.h>
 #include <limits.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
 #include <sys/stat.h>
 #include <sys/types.h>
+#include <unistd.h>
 
 #include <lxc/lxccontainer.h>
 #include <lxc/version.h>
 
 #include "arguments.h"
-#include "namespace.h"
+#include "compiler.h"
+#include "config.h"
 #include "initutils.h"
+#include "namespace.h"
 
 static int build_shortopts(const struct option *a_options, char *a_shortopts,
 			   size_t a_size)
@@ -87,8 +91,8 @@ is2big:
 	return -1;
 }
 
-static void print_usage_exit(const struct option longopts[],
-			     const struct lxc_arguments *a_args)
+__noreturn static void print_usage_exit(const struct option longopts[],
+					  const struct lxc_arguments *a_args)
 
 {
 	int i;
@@ -134,13 +138,14 @@ static void print_usage_exit(const struct option longopts[],
 	exit(0);
 }
 
-static void print_version_exit()
+__noreturn static void print_version_exit()
 {
 	printf("%s\n", lxc_get_version());
 	exit(0);
 }
 
-static void print_help_exit(const struct lxc_arguments *args, int code)
+__noreturn static void print_help_exit(const struct lxc_arguments *args,
+					 int code)
 {
 	fprintf(stderr, "\
 Usage: %s %s\
