@@ -18,7 +18,9 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#define _GNU_SOURCE
+#ifndef _GNU_SOURCE
+#define _GNU_SOURCE 1
+#endif
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -27,6 +29,7 @@
 #include <lxc/lxccontainer.h>
 
 #include "arguments.h"
+#include "config.h"
 #include "list.h"
 #include "log.h"
 #include "utils.h"
@@ -318,7 +321,7 @@ static int toss_list(struct lxc_list *c_groups_list)
 
 int main(int argc, char *argv[])
 {
-	int count = 0, i = 0, ret = 0;
+	int count = 0, failed = 0, i = 0, ret = 0;
 	struct lxc_list *cmd_group;
 	struct lxc_container **containers = NULL;
 	struct lxc_list **c_groups_lists = NULL;
@@ -414,7 +417,7 @@ int main(int argc, char *argv[])
 				}
 			}
 
-			/* We have a candidate continer to process */
+			/* We have a candidate container to process */
 			c->want_daemonize(c, 1);
 
 			if (my_args.shutdown) {
@@ -491,11 +494,15 @@ int main(int argc, char *argv[])
 
 	}
 
-	/* clean up any lingering detritus */
+	/* clean up any lingering detritus, if container exists here
+	 * then it must have failed to start.
+	 */
+	failed = 0;
 	for (i = 0; i < count; i++) {
-		if (containers[i])
+		if (containers[i]) {
+			failed++;
 			lxc_container_put(containers[i]);
-
+		}
 		if (c_groups_lists && c_groups_lists[i])
 			toss_list(c_groups_lists[i]);
 	}
@@ -504,5 +511,10 @@ int main(int argc, char *argv[])
 	toss_list(cmd_groups_list);
 	free(containers);
 
+	if (failed == count)
+		exit(1);	/* Total failure */
+	else if (failed > 0)
+		exit(2);	/* Partial failure */
+
 	exit(EXIT_SUCCESS);
 }
