@@ -18,11 +18,16 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#ifndef _GNU_SOURCE
+#define _GNU_SOURCE 1
+#endif
 #include <stdio.h>
 #include <string.h>
 
 #include <lxc/lxccontainer.h>
 
+#include "config.h"
+
 struct lxc_config_items {
 	char *name;
 };
