@@ -21,36 +21,61 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
-#define _GNU_SOURCE
+#ifndef _GNU_SOURCE
+#define _GNU_SOURCE 1
+#endif
 #include <errno.h>
 #include <fcntl.h>
 #include <libgen.h>
 #include <poll.h>
+#include <signal.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <signal.h>
 #include <string.h>
-#include <unistd.h>
 #include <sys/ioctl.h>
 #include <sys/param.h>
 #include <sys/stat.h>
 #include <sys/types.h>
+#include <unistd.h>
 
 #include <lxc/lxccontainer.h>
 
 #include "arguments.h"
+#include "config.h"
 #include "log.h"
 #include "utils.h"
 
 lxc_log_define(lxc_console, lxc);
 
-static char etoc(const char *expr)
-{
-	/* returns "control code" of given expression */
-	char c = expr[0] == '^' ? expr[1] : expr[0];
+static int my_parser(struct lxc_arguments *args, int c, char *arg);
+static char etoc(const char *expr);
 
-	return 1 + ((c > 'Z') ? (c - 'a') : (c - 'Z'));
-}
+static const struct option my_longopts[] = {
+	{"tty", required_argument, 0, 't'},
+	{"escape", required_argument, 0, 'e'},
+	LXC_COMMON_OPTIONS
+};
+
+static struct lxc_arguments my_args = {
+	.progname     = "lxc-console",
+	.help         = "\
+--name=NAME [--tty NUMBER]\n\
+\n\
+lxc-console logs on the container with the identifier NAME\n\
+\n\
+Options :\n\
+  -n, --name=NAME      NAME of the container\n\
+  -t, --tty=NUMBER     console tty number\n\
+  -e, --escape=PREFIX  prefix for escape command\n\
+  --rcfile=FILE        Load configuration file FILE\n",
+	.options      = my_longopts,
+	.parser       = my_parser,
+	.checker      = NULL,
+	.log_priority = "ERROR",
+	.log_file     = "none",
+	.ttynum       = -1,
+	.escape       = 1,
+};
 
 static int my_parser(struct lxc_arguments *args, int c, char *arg)
 {
@@ -67,30 +92,13 @@ static int my_parser(struct lxc_arguments *args, int c, char *arg)
 	return 0;
 }
 
-static const struct option my_longopts[] = {
-	{"tty", required_argument, 0, 't'},
-	{"escape", required_argument, 0, 'e'},
-	LXC_COMMON_OPTIONS
-};
+static char etoc(const char *expr)
+{
+	/* returns "control code" of given expression */
+	char c = expr[0] == '^' ? expr[1] : expr[0];
 
-static struct lxc_arguments my_args = {
-	.progname = "lxc-console",
-	.help     = "\
---name=NAME [--tty NUMBER]\n\
-\n\
-lxc-console logs on the container with the identifier NAME\n\
-\n\
-Options :\n\
-  -n, --name=NAME      NAME of the container\n\
-  -t, --tty=NUMBER     console tty number\n\
-  -e, --escape=PREFIX  prefix for escape command\n\
-  --rcfile=FILE        Load configuration file FILE\n",
-	.options  = my_longopts,
-	.parser   = my_parser,
-	.checker  = NULL,
-	.ttynum = -1,
-	.escape = 1,
-};
+	return 1 + ((c > 'Z') ? (c - 'a') : (c - 'Z'));
+}
 
 int main(int argc, char *argv[])
 {
@@ -98,22 +106,18 @@ int main(int argc, char *argv[])
 	struct lxc_container *c;
 	struct lxc_log log;
 
-	ret = lxc_arguments_parse(&my_args, argc, argv);
-	if (ret)
+	if (lxc_arguments_parse(&my_args, argc, argv))
 		exit(EXIT_FAILURE);
 
-	/* Only create log if explicitly instructed */
-	if (my_args.log_file || my_args.log_priority) {
-		log.name = my_args.name;
-		log.file = my_args.log_file;
-		log.level = my_args.log_priority;
-		log.prefix = my_args.progname;
-		log.quiet = my_args.quiet;
-		log.lxcpath = my_args.lxcpath[0];
+	log.name = my_args.name;
+	log.file = my_args.log_file;
+	log.level = my_args.log_priority;
+	log.prefix = my_args.progname;
+	log.quiet = my_args.quiet;
+	log.lxcpath = my_args.lxcpath[0];
 
-		if (lxc_log_init(&log))
-			exit(EXIT_FAILURE);
-	}
+	if (lxc_log_init(&log))
+		exit(EXIT_FAILURE);
 
 	c = lxc_container_new(my_args.name, my_args.lxcpath[0]);
 	if (!c) {
