@@ -19,35 +19,35 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
-#define _GNU_SOURCE
+#ifndef _GNU_SOURCE
+#define _GNU_SOURCE 1
+#endif
 #include <libgen.h>
 #include <limits.h>
 #include <stdio.h>
 #include <string.h>
-#include <unistd.h>
 #include <sys/types.h>
+#include <unistd.h>
 
 #include <lxc/lxccontainer.h>
 
+#include "../../include/netns_ifaddrs.h"
 #include "arguments.h"
+#include "config.h"
 #include "log.h"
 #include "utils.h"
 
 lxc_log_define(lxc_device, lxc);
 
-#if HAVE_IFADDRS_H
-#include <ifaddrs.h>
-#else
-#include "include/ifaddrs.h"
-#endif
+static bool is_interface(const char *dev_name, pid_t pid);
 
 static const struct option my_longopts[] = {
 	LXC_COMMON_OPTIONS
 };
 
 static struct lxc_arguments my_args = {
-	.progname = "lxc-device",
-	.help     = "\
+	.progname     = "lxc-device",
+	.help         = "\
 --name=NAME -- add|del DEV\n\
 \n\
 lxc-device attach or detach DEV to or from container.\n\
@@ -55,9 +55,11 @@ lxc-device attach or detach DEV to or from container.\n\
 Options :\n\
   -n, --name=NAME      NAME of the container\n\
   --rcfile=FILE        Load configuration file FILE\n",
-	.options  = my_longopts,
-	.parser   = NULL,
-	.checker  = NULL,
+	.options      = my_longopts,
+	.parser       = NULL,
+	.checker      = NULL,
+	.log_priority = "ERROR",
+	.log_file     = "none",
 };
 
 static bool is_interface(const char *dev_name, pid_t pid)
@@ -69,7 +71,7 @@ static bool is_interface(const char *dev_name, pid_t pid)
 	}
 
 	if (p == 0) {
-		struct ifaddrs *interfaceArray = NULL, *tempIfAddr = NULL;
+		struct netns_ifaddrs *interfaceArray = NULL, *tempIfAddr = NULL;
 
 		if (!switch_to_ns(pid, "net")) {
 			ERROR("Failed to enter netns of container");
@@ -77,7 +79,7 @@ static bool is_interface(const char *dev_name, pid_t pid)
 		}
 
 		/* Grab the list of interfaces */
-		if (getifaddrs(&interfaceArray)) {
+		if (netns_getifaddrs(&interfaceArray, -1, &(bool){false})) {
 			ERROR("Failed to get interfaces list");
 			_exit(-1);
 		}
@@ -110,25 +112,22 @@ int main(int argc, char *argv[])
 	}
 
 	if (lxc_arguments_parse(&my_args, argc, argv))
-		goto err;
+		exit(EXIT_FAILURE);
 
-	/* Only create log if explicitly instructed */
-	if (my_args.log_file || my_args.log_priority) {
-		log.name = my_args.name;
-		log.file = my_args.log_file;
-		log.level = my_args.log_priority;
-		log.prefix = my_args.progname;
-		log.quiet = my_args.quiet;
-		log.lxcpath = my_args.lxcpath[0];
+	log.name = my_args.name;
+	log.file = my_args.log_file;
+	log.level = my_args.log_priority;
+	log.prefix = my_args.progname;
+	log.quiet = my_args.quiet;
+	log.lxcpath = my_args.lxcpath[0];
 
-		if (lxc_log_init(&log))
-			exit(EXIT_FAILURE);
-	}
+	if (lxc_log_init(&log))
+		exit(EXIT_FAILURE);
 
 	c = lxc_container_new(my_args.name, my_args.lxcpath[0]);
 	if (!c) {
 		ERROR("%s doesn't exist", my_args.name);
-		goto err;
+		exit(EXIT_FAILURE);
 	}
 
 	if (my_args.rcfile) {
@@ -136,65 +135,60 @@ int main(int argc, char *argv[])
 
 		if (!c->load_config(c, my_args.rcfile)) {
 			ERROR("Failed to load rcfile");
-			goto err1;
+			goto err;
 		}
 
 		c->configfile = strdup(my_args.rcfile);
 		if (!c->configfile) {
 			ERROR("Out of memory setting new config filename");
-			goto err1;
+			goto err;
 		}
 	}
 
 	if (!c->is_running(c)) {
 		ERROR("Container %s is not running", c->name);
-		goto err1;
+		goto err;
 	}
 
 	if (my_args.argc < 2) {
 		ERROR("Error: no command given (Please see --help output)");
-		goto err1;
+		goto err;
 	}
 
 	cmd = my_args.argv[0];
 	dev_name = my_args.argv[1];
+
 	if (my_args.argc < 3)
 		dst_name = dev_name;
 	else
 		dst_name = my_args.argv[2];
 
 	if (strncmp(cmd, "add", strlen(cmd)) == 0) {
-		if (is_interface(dev_name, 1)) {
+		if (is_interface(dev_name, 1))
 			ret = c->attach_interface(c, dev_name, dst_name);
-		} else {
+		else
 			ret = c->add_device_node(c, dev_name, dst_name);
-		}
-
 		if (ret != true) {
 			ERROR("Failed to add %s to %s", dev_name, c->name);
-			goto err1;
+			goto err;
 		}
 	} else if (strncmp(cmd, "del", strlen(cmd)) == 0) {
-		if (is_interface(dev_name, c->init_pid(c))) {
+		if (is_interface(dev_name, c->init_pid(c)))
 			ret = c->detach_interface(c, dev_name, dst_name);
-		} else {
+		else
 			ret = c->remove_device_node(c, dev_name, dst_name);
-		}
-
 		if (ret != true) {
 			ERROR("Failed to del %s from %s", dev_name, c->name);
-			goto err1;
+			goto err;
 		}
 	} else {
 		ERROR("Error: Please use add or del (Please see --help output)");
-		goto err1;
+		goto err;
 	}
 
 	exit(EXIT_SUCCESS);
 
-err1:
-	lxc_container_put(c);
-
 err:
+	lxc_container_put(c);
 	exit(EXIT_FAILURE);
 }
