@@ -21,7 +21,9 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
-#define _GNU_SOURCE
+#ifndef _GNU_SOURCE
+#define _GNU_SOURCE 1
+#endif
 #define __STDC_FORMAT_MACROS
 #include <dirent.h>
 #include <errno.h>
@@ -34,19 +36,21 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
 #include <sys/param.h>
 #include <sys/socket.h>
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <sys/un.h>
 #include <sys/wait.h>
+#include <unistd.h>
 
 #include <lxc/lxccontainer.h>
 
 #include "af_unix.h"
 #include "arguments.h"
+#include "config.h"
 #include "log.h"
+#include "macro.h"
 #include "monitor.h"
 #include "state.h"
 #include "utils.h"
@@ -156,7 +160,7 @@ static int lxc_tool_monitord_spawn(const char *lxcpath)
 {
 	int ret;
 	int pipefd[2];
-	char pipefd_str[LXC_NUMSTRLEN64];
+	char pipefd_str[INTTYPE_TO_STRLEN(int)];
 	pid_t pid1, pid2;
 
 	char *const args[] = {
@@ -223,8 +227,8 @@ static int lxc_tool_monitord_spawn(const char *lxcpath)
 
 	close(pipefd[0]);
 
-	ret = snprintf(pipefd_str, LXC_NUMSTRLEN64, "%d", pipefd[1]);
-	if (ret < 0 || ret >= LXC_NUMSTRLEN64) {
+	ret = snprintf(pipefd_str, sizeof(pipefd_str), "%d", pipefd[1]);
+	if (ret < 0 || ret >= sizeof(pipefd_str)) {
 		ERROR("Failed to create pid argument to pass to monitord");
 		_exit(EXIT_FAILURE);
 	}
